% This is file "dbsj.cls",
% LaTeX Class File for the DBSJ Japanese Journal.
%
\NeedsTeXFormat{LaTeX2e}
\ProvidesPackage{dbsj}
%  [2018/11/30 v0.1.0]% generated by Kento Sugiura
%  [2019/04/16 v0.2.0]% updated by Kento Sugiura
%  [2019/12/25 v0.2.1]% fixed by Kento Sugiura
%  [2019/12/26 v0.3.0]% updated by Kento Sugiura
%  [2019/12/28 v0.4.0]% updated by Kento Sugiura
  [2019/12/29 v0.5.0]% updated by Kento Sugiura

% enable english writings
\DeclareOption{english}{
  \PassOptionsToClass{\CurrentOption}{bxjsarticle}
}

% Fallback
\DeclareOption*{
  \ClassWarning{bxjsarticle}{Unknown option '\CurrentOption'}
}

% Process given options
\ProcessOptions\relax

% Load a basic class and packages
\LoadClass[
  a4paper,
  9pt,
  twocolumn,
  notitlepage,
  autodetect-engine,
  dvi=dvipdfmx,
  ja=standard,
]{bxjsarticle}
\RequirePackage{fancyhdr}
\RequirePackage{graphicx}

%----------------------------------------------------------------------------- %
% Layout settings
%----------------------------------------------------------------------------- %
% set margins
\setpagelayout*{
  headheight=18pt,
  footskip=0.03367\paperheight,
  headsep=\footskip-\topskip,
  includeheadfoot,
  left=15truemm,
  right=15truemm,
  top=20truemm,
  bottom=15truemm,
}

% Use header/footer
\pagestyle{fancy}

% Default header and footer layouts
\fancyhf{} % Clear the original settings
\lhead{\sffamily\NumToCategory{\@Category}}
\rhead{\sffamily%
  \if@english
    DBSJ Journal\\%
    Vol.~\@Volume, Article No.~\@ArticleNumber, \EngMonth\ \@Year
  \else
    日本データベース学会和文論文誌\\%
    Vol.~\@Volume-J, Article No.~\@ArticleNumber, \@Year 年 \@Month 月
  \fi
}
\cfoot{\thepage}
\rfoot{%
  \includegraphics[height=5truemm]{./DBSJ-logo.png}
}
\renewcommand{\headrulewidth}{0.4pt}
\renewcommand{\footrulewidth}{0pt}

\newcommand{\EngMonth}{%
  \ifcase\@Month\or
    January\or February\or March\or April\or May\or June\or
    July\or August\or September\or October\or November\or December\fi
}

%----------------------------------------------------------------------------- %
% Macros to input paper category, volume, article number, and publish date.
%----------------------------------------------------------------------------- %
\newcommand{\@Category}{1}
\newcommand{\Category}[1]{%
  \renewcommand{\@Category}{#1}
}
\newcommand{\NumToCategory}[1]{%
  \if@english
    \ifcase #1\or
      Regular Paper\or System Development and Industrial Paper\or
      Survey Paper\or Special Contribution\fi
  \else
    \ifcase #1\or
      一般論文\or システム開発・産業論文\or サーベイ論文\or 特別寄稿\fi
  \fi
}

\newcommand{\@Volume}{0}
\newcommand{\Volume}[1]{%
  \renewcommand{\@Volume}{#1}
}

\newcommand{\@ArticleNumber}{0}
\newcommand{\ArticleNumber}[1]{%
  \renewcommand{\@ArticleNumber}{#1}
}

\newcommand{\@Year}{2019}
\newcommand{\Year}[1]{%
  \renewcommand{\@Year}{#1}
}

\newcommand{\@Month}{1}
\newcommand{\Month}[1]{%
  \renewcommand{\@Month}{#1}
}

%------------------------------------------------------------------------------%
% Macros to input a title, authors, and affiliations
%------------------------------------------------------------------------------%
\renewcommand{\title}[1]{
  \def\@title{#1}
}

\newcount\@authorCnt
\@authorCnt=1
\renewcommand{\author}[4]{
  \expandafter\def\csname @author\number\@authorCnt\endcsname{#1}
  \expandafter\def\csname @member\number\@authorCnt\endcsname{#2}
  \expandafter\def\csname @affiliation\number\@authorCnt\endcsname{#3}
  \expandafter\def\csname @email\number\@authorCnt\endcsname{#4}
  \advance\@authorCnt by1
}

\newcommand{\Member}[1]{%
  \if@english
    \ifcase #1\or
      Regular member\or Honorary member\or Student member\or Non member\fi
  \else
    \ifcase #1\or
      正会員\or 名誉会員\or 学生会員\or 非会員\fi
  \fi
}

%------------------------------------------------------------------------------%
% Macros to modify the descriptions of authors and affiliations for title layout
%------------------------------------------------------------------------------%

% generate a list of authors' names
\newcommand{\@authorList}{%
  \@tempcnta=1
  \loop\ifnum\@tempcnta<\@authorCnt
    \mbox{\sffamily%
      \csname @author\number\@tempcnta\endcsname%
      $^{\number\@tempcnta}$%
    }%
    \quad
    \advance\@tempcnta by1
  \repeat
}

% generate a list of affiliations' names
\newcommand{\@afflList}{%
  \@tempcnta=1
  \loop\ifnum\@tempcnta<\@authorCnt
    \begin{minipage}[t]{6pt}%
      $^{\number\@tempcnta}$%
    \end{minipage}%
    \begin{minipage}[t]{\linewidth-7pt}%
      \Member{\csname @member\number\@tempcnta\endcsname}\quad%
      \csname @affiliation\number\@tempcnta\endcsname\\%
      \mbox{\ttfamily\csname @email\number\@tempcnta\endcsname}%
    \end{minipage}%
    \advance\@tempcnta by1
    \ifnum\@tempcnta<\@authorCnt
      \\
    \fi
  \repeat
}

%----------------------------------------------------------------------------- %
% Override "\maketitle"
%----------------------------------------------------------------------------- %
\renewcommand{\maketitle}{\par
%----------------------------- modified ------------------------------%
\begingroup
  \renewcommand\thefootnote{\@fnsymbol\c@footnote}%
  \def\@makefnmark{\rlap{\@textsuperscript{\normalfont\@thefnmark}}}%
  \long\def\@makefntext##1{\advance\leftskip 1\jsZw
    \parindent 1\jsZw\noindent
    \llap{\@textsuperscript{\normalfont\@thefnmark}\hskip0.3\jsZw}##1}%
  \@maketitle
  \long\def\@makefntext##1{\parindent 0pt\noindent##1}%
  \footnotetext{\@afflList}%
  \plainifnotempty
  \@thanks
\endgroup
%---------------------------------------------------------------------%
\setcounter{footnote}{0}%
\global\let\thanks\relax
\global\let\maketitle\relax
\global\let\@thanks\@empty
\global\let\@author\@empty
\global\let\@date\@empty
\global\let\@title\@empty
\global\let\title\relax
\global\let\author\relax
\global\let\date\relax
\global\let\and\relax
\bxjs@annihilate@subtitle
\thispagestyle{fancy}% added for page header
}

\def\@maketitle{%
\newpage\null
\begin{flushleft}%
  \let\footnote\thanks
  \vskip -2.5em
  \noindent{\LARGE\sffamily\@title\par}%
  \vskip 2em
  {\Large\sffamily
  \lineskip .5em
  \tabcolsep 0pt
  \begin{tabular}[t]{p{\linewidth}}%
    \@authorList
  \end{tabular}\par}%
\end{flushleft}%
\par\vskip 1em
}

%----------------------------------------------------------------------------- %
% Override "abstract" environment
%----------------------------------------------------------------------------- %
\renewenvironment{abstract}{\sffamily}{\vskip 1em}

%----------------------------------------------------------------------------- %
% Override "thebibliography" environment
%----------------------------------------------------------------------------- %
\renewenvironment{thebibliography}[1]{%
  \@jsc@warnoldfontcmdexceptiontrue
  \global\let\presectionname\relax
  \global\let\postsectionname\relax
  \section*{\refname}\@mkboth{\refname}{\refname}%
    \list{\@biblabel{\@arabic\c@enumiv}}%
    {\settowidth\labelwidth{\@biblabel{#1}}%
      \leftmargin\labelwidth
      \advance\leftmargin\labelsep
      %-------- modified ---------%
      \small
      \setlength\baselineskip{10pt}
      %---------------------------%
      \@openbib@code
      \usecounter{enumiv}%
      \let\p@enumiv\@empty
      \renewcommand\theenumiv{\@arabic\c@enumiv}}%
   \sloppy
   \clubpenalty4000
   \@clubpenalty\clubpenalty
   \widowpenalty4000%
   \sfcode`\.\@m
}
{\def\@noitemerr
{\@latex@warning{Empty `thebibliography' environment}}%
\endlist}